skretrieval.core.platform package
=================================

Submodules
----------

skretrieval.core.platform.balloon module
----------------------------------------

.. automodule:: skretrieval.core.platform.balloon
    :members:
    :undoc-members:
    :show-inheritance:

skretrieval.core.platform.satellite module
------------------------------------------

.. automodule:: skretrieval.core.platform.satellite
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: skretrieval.core.platform
    :members:
    :undoc-members:
    :show-inheritance:
